@@ -601,7 +601,18 @@ class ImagingReduction(object):
             hdr = hdu[0].header
 
             for k, sk in zip(keywords, keywords_short):
-                files_info.loc[f, sk] = hdr.get(k)
+                if k == 'HIERARCH ESO INS4 DROT2 BEGIN':
+                    # in June 2021 ESO changed INS4 DROT2 BEGIN to INS4 DROT2 START
+                    v_begin = hdr.get('HIERARCH ESO INS4 DROT2 BEGIN')
+                    v_start = hdr.get('HIERARCH ESO INS4 DROT2 START')
+                    files_info.loc[f, sk] = v_begin if v_begin else v_start
+                elif k == 'HIERARCH ESO INS4 DROT3 BEGIN':
+                    # in June 2021 ESO changed INS4 DROT3 BEGIN to INS4 DROT3 START
+                    v_begin = hdr.get('HIERARCH ESO INS3 DROT2 BEGIN')
+                    v_start = hdr.get('HIERARCH ESO INS3 DROT2 START')
+                    files_info.loc[f, sk] = v_begin if v_begin else v_start
+                else:
+                    files_info.loc[f, sk] = hdr.get(k)
 
             hdu.close()
 
